package
Version:
v1.0.3
Opens a new window with list of versions in this module.
Published: Feb 5, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DBConfig struct {
Host string `json:"Host"`
Port int `json:"Port"`
User string `json:"User"`
Password string `json:"Password"`
DBName string `json:"DBName"`
SSLMode string `json:"SSLMode"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.